package com.younike.system.service;

import com.younike.system.domain.Agent;

import java.util.List;

/**
 * 商户代理商Service接口
 * 
 * @author dail
 * @date 2022-03-09
 */
public interface IAgentService {
    /**
     * 查询商户代理商
     * 
     * @param agentId 商户代理商主键
     * @return 商户代理商
     */
    Agent selectAgentByAgentId(Long agentId);

    /**
     * 查询商户代理商列表
     * 
     * @param agent 商户代理商
     * @return 商户代理商集合
     */
    List<Agent> selectAgentList(Agent agent);

    /**
     * 新增商户代理商
     * 
     * @param agent 商户代理商
     * @return 结果
     */
    int insertAgent(Agent agent);

    /**
     * 修改商户代理商
     * 
     * @param agent 商户代理商
     * @return 结果
     */
    int updateAgent(Agent agent);

    /**
     * 批量删除商户代理商
     * 
     * @param agentIds 需要删除的商户代理商主键集合
     * @return 结果
     */
    int deleteAgentByAgentIds(Long[] agentIds);

    /**
     * 删除商户代理商信息
     * 
     * @param agentId 商户代理商主键
     * @return 结果
     */
    int deleteAgentByAgentId(Long agentId);

    /**
     * 逻辑删除商户代理商信息
     * @param agentId
     * @return
     */
    int logicalRemoveById(Long agentId);
}
